Recent Alaska Court of Appeals Slip Opinions - Alaska Court System
Description: Alaska Court of Appeals Decisions
Keywords: Alaska Court of Appeals, decisions, opinions, slip opinions, published opinions, Alaska, Court

Skip Navigation

# Alaska Court System

Home » Appellate Courts » Recent Court of Appeals Slip Opinions

## Recent Court of Appeals Slip Opinions

Opinions are removed from this site once they are printed in the Pacific Reporter, the designated official reporter of Alaskan appellate decisions. Opinions from 1980 to present can also be found in the law library's Alaska Case Law Service.

Court of Appeals slip opinions are subject to correction before publication in the Pacific Reporter. Please bring errors to the attention of:

Clerk of the Appellate Courts
303 K Street
Anchorage AK 99501
phone: 907-264-0608
fax: 907-264-0878
email: corrections@akcourts.us

See also:
Information about the appellate courts' opinion notification service

### 2015

#### August 7, 2015

- 2466 A-11631 Carter v. State
- 2467 A-11170 Saepharn v. State

#### July 31, 2015

- 2465 A-11071 Rogers v. State

#### July 24, 2015

- 2464 A-11614 Augustine v. State

#### July 17, 2015

- 2463 A-12101 Alexiadis v. State

#### July 10, 2015

- 2462 A-11078 Shorthill v. State

#### July 2, 2015

- 2460 A-11545 Lenz v. State
- 2461 A-11356 Velarde v. State

#### June 26, 2015

- 2458 A-11123/A-11133 Byford v. State
- 2459 A-11422 Lampley v. State

#### June 19, 2015

- 2456 A-10971 Snowden v. State
- 2457 A-11778 Buxton v. State

#### June 12, 2015

- No opinions issued.

#### June 5, 2015

- No opinions issued.

#### May 29, 2015

- 2454 A-11748 State v. Pete, 351 P3d 346
- 2455 A-11390 Smith v. State, 349 P3d 1087

#### May 22, 2015

- No opinions issued.

#### May 15, 2015

- No opinions issued.

#### May 8, 2015

- 2452 A-11746 Selvester v. State, 349 P3d 1085
- 2453 A-11002 Simon v. State, 349 P3d 191

#### May 1, 2015

- No opinions issued.

#### April 24, 2015

- 2450 A-11739 State v. W.P., a minor, 349 P3d 181
- 2451 A-11329 Downs v. State, 349 P3d 189

#### April 17, 2015

- No opinions issued.

#### April 10, 2015

- 2449 A-10882 Kelley v. State, 347 P3d 1012

#### April 3, 2015

- 2448 A-11094 Gibson v. State, 346 P3d 977

#### January - March 2015

- 2440 A-11093 Kankanton v. State, 342 P3d 840
- 2441 A-11052 Waterman v. State, 342 P3d 1261
- 2442 A-12147 Simmons v. State, 344 P3d 833
- 2443 A-11734 State v. Stidston, 343 P3d 911
- 2444 A-12053 Alaska Public Defender Agency v. Superior Court, Third Judicial District, Anchorage, 343 P3d 914
- 2445 A-11191 Murray v. State, 344 P3d 835
- 2446 A-11580/A-11620 Phillip v. State, 347 P3d 128
- 2447 A-10587 Wright v. State, 347 P3d 1000

Go to top of page | Return to Appellate Courts Homepage | Return to Court Homepage

### 2014

#### July - December 2014

- 2419 A-11404 Simants v. State, 329 P3d 1033
- 2420 A-11173 Phillips v. State, 330 P3d 941
- 2421 A-10821 Warlick v. State, 330 P3d 946
- 2422 A-11006 Young v. State, 331 P3d 1276
- 2423 A-11654 Wassillie v. State, 331 P3d 1285
- 2424 A-11085 Siedentop v. State, 337 P3d 1
- 2425 A-11058 Fyfe v. State, 334 P3d 183
- 2426 A-11068 Johnson v. State, 334 P3d 701
- 2427 A-11043 Tickett v. State, 334 P3d 708
- 2428 A-11042 Gamble v. State, 334 P3d 714
- 2429 A-11178 Morris v. State, 334 P3d 1244
- 2430 A-11881 Geisinger v. State, 334 P3d 1241
- 2431 A-11389 State v. Leighton, 336 P3d 713
- 2432 A-10855 Crawford v. State, 337 P3d 4
- 2433 A-11552 State v. Finley, 337 P3d 527
- 2434 A-10776 Anderson v. State, 337 P3d 534
- 2435 A-11492 Pletcher v. State, 338 P3d 953
- 2436 A-11274 Rae v. State, 338 P3d 961
- 2437 A-11198 Stiffarm v. State, 339 P3d 1021
- 2438 A-11424 Daniels v. State, 339 P3d 1027
- 2439 A-10835 Jackson v. State, 342 P3d 1254

Go to top of page | Return to Appellate Courts Homepage | Return to Court Homepage

#### January - June 2014

- 2410 A-10858 Yako v. State, 317 P3d 627
- 2411 A-11136 Leggett v. State, 320 P3d 311
- 2412 A-10946 Barr v. State, 320 P3d 816
- 2413 A-10800 Mund v. State, 325 P3d 535
- 2414 A-11501 Patterson v. State, 323 P3d 65
- 2415 A-11549 Gou-Leonhardt v. State, 323 P3d 700
- 2416 A-11561 Hannam v. State, 327 P3d 209
- 2417 A-11088 Roth v. State, 329 P3d 1023
- 2418 A-11159 Anthony v. State, 329 P3d 1027

Go to top of page | Return to Appellate Courts Homepage | Return to Court Homepage